.. _utilipy-installation:

============
Installation
============

|Code Size|

**********
With `pip`
**********

.. container::

	|PyPI| |PyPI Format|

*utilipy* requires `Astropy <https://www.astropy.org>`_ as a pre-requisite, for package configuration.

The easiest way to get *utilipy* is to install with `pip <https://pypi.org/project/utilipy/>`_. To install with pip::

    pip install utilipy


***********
From source
***********

To install the latest version, or from a branch, *utilipy* can be installed from `source <https://github.com/nstarman/utilipy.git>`_.

From the command line.
::

	cd folder/in/which/to/install

	git clone https://github.com/nstarman/utilipy.git

	cd utilipy

	python setup.py install



.. |PyPI| image:: https://badge.fury.io/py/utilipy.svg
   :target: https://badge.fury.io/py/utilipy

.. |PyPI Format| image:: https://img.shields.io/pypi/format/utilipy?style=flat
   :alt: PyPI - Format

.. |Code Size| image:: https://img.shields.io/github/languages/code-size/nstarman/utilipy?style=flat
   :alt: GitHub code size in bytes
